==> gromacs_2021.4.orig.tar.gz: gromacs-2021.4/src/gromacs/utility/baseversion_gen.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2010,2012,2013,2014,2015 by the GROMACS development team.
 * Copyright (c) 2018,2019,2020,2021, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \internal \file
 * \brief
 * Declares variables that hold generated version information.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_BASEVERSION_GEN_H
#define GMX_UTILITY_BASEVERSION_GEN_H

/*! \cond internal */
//! \addtogroup module_utility
//! \{

//! Version string, containing the version, date, and abbreviated hash.
extern const char _gmx_ver_string[];
//! Full git hash of the latest commit.
extern const char _gmx_full_git_hash[];
//! Full git hash of the latest commit in a central \Gromacs repository.
extern const char _gmx_central_base_hash[];
/*! \brief
 *  DOI string for the \Gromacs source code populated by CMake.
 *
 *  The variable is populated with the generated DOI string
 *  by CMake when the build of a release version is
 *  requested by Jenkins. Allows identification and
 *  referencing of different \Gromacs releases.
 */
extern const char gmxSourceDoiString[];

//! \}
//! \endcond

#endif

==> gromacs_2023.3.orig.tar.gz: gromacs-2023.3/src/gromacs/utility/baseversion_gen.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright 2010- The GROMACS Authors
 * and the project initiators Erik Lindahl, Berk Hess and David van der Spoel.
 * Consult the AUTHORS/COPYING files and https://www.gromacs.org for details.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * https://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at https://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out https://www.gromacs.org.
 */
/*! \internal \file
 * \brief
 * Declares variables that hold generated version information.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_BASEVERSION_GEN_H
#define GMX_UTILITY_BASEVERSION_GEN_H

/*! \cond internal */
//! \addtogroup module_utility
//! \{

//! Version string, containing the version, date, and abbreviated hash.
extern const char gmx_ver_string[];
//! Full git hash of the latest commit.
extern const char gmx_full_git_hash[];
//! Full git hash of the latest commit in a central \Gromacs repository.
extern const char gmx_central_base_hash[];
/*! \brief
 *  DOI string for the \Gromacs source code populated by CMake.
 *
 *  The variable is populated with the generated DOI string
 *  by CMake when the build of a release version is
 *  requested. Allows identification and
 *  referencing of different \Gromacs releases.
 */
extern const char gmxSourceDoiString[];

//! \}
//! \endcond

#endif
